@@ -221,6 +221,9 @@ void                  gst_rtsp_media_set_shared       (GstRTSPMedia *media, gboo
 GST_RTSP_SERVER_API
 gboolean              gst_rtsp_media_is_shared        (GstRTSPMedia *media);
 
+GST_RTSP_SERVER_API
+gboolean              gst_rtsp_media_can_be_shared    (GstRTSPMedia *media);
+
 GST_RTSP_SERVER_API
 void                  gst_rtsp_media_set_stop_on_disconnect (GstRTSPMedia *media, gboolean stop_on_disconnect);
 
@@ -275,6 +278,20 @@ void                  gst_rtsp_media_set_buffer_size  (GstRTSPMedia *media, guin
 GST_RTSP_SERVER_API
 guint                 gst_rtsp_media_get_buffer_size  (GstRTSPMedia *media);
 
+GST_RTSP_SERVER_API
+void                  gst_rtsp_media_set_ensure_keyunit_on_start (GstRTSPMedia* media,
+                                                                  gboolean ensure_keyunit_on_start);
+
+GST_RTSP_SERVER_API
+gboolean              gst_rtsp_media_get_ensure_keyunit_on_start (GstRTSPMedia* media);
+
+GST_RTSP_SERVER_API
+void                  gst_rtsp_media_set_ensure_keyunit_on_start_timeout (GstRTSPMedia* media,
+                                                                          guint timeout);
+
+GST_RTSP_SERVER_API
+guint          gst_rtsp_media_get_ensure_keyunit_on_start_timeout (GstRTSPMedia* media);
+
 GST_RTSP_SERVER_API
 void                  gst_rtsp_media_set_retransmission_time  (GstRTSPMedia *media, GstClockTime time);
 
