@@ -343,20 +343,9 @@ gst_rtsp_session_release_media (GstRTSPSession * sess,
   return more;
 }
 
-/**
- * gst_rtsp_session_get_media:
- * @sess: a #GstRTSPSession
- * @path: the path for the media
- * @matched: (out): the amount of matched characters
- *
- * Get the session media for @path. @matched will contain the number of matched
- * characters of @path.
- *
- * Returns: (transfer none) (nullable): the configuration for @path in @sess.
- */
-GstRTSPSessionMedia *
-gst_rtsp_session_get_media (GstRTSPSession * sess, const gchar * path,
-    gint * matched)
+static GstRTSPSessionMedia *
+_gst_rtsp_session_get_media (GstRTSPSession * sess, const gchar * path,
+    gint * matched, gboolean dup)
 {
   GstRTSPSessionPrivate *priv;
   GstRTSPSessionMedia *result;
@@ -384,6 +373,9 @@ gst_rtsp_session_get_media (GstRTSPSession * sess, const gchar * path,
       }
     }
   }
+
+  if (result && dup)
+    result = g_object_ref (result);
   g_mutex_unlock (&priv->lock);
 
   *matched = best;
@@ -391,11 +383,50 @@ gst_rtsp_session_get_media (GstRTSPSession * sess, const gchar * path,
   return result;
 }
 
+/**
+ * gst_rtsp_session_get_media:
+ * @sess: a #GstRTSPSession
+ * @path: the path for the media
+ * @matched: (out): the amount of matched characters
+ *
+ * Gets the session media for @path. @matched will contain the number of matched
+ * characters of @path.
+ *
+ * Returns: (transfer none) (nullable): the configuration for @path in @sess.
+ */
+GstRTSPSessionMedia *
+gst_rtsp_session_get_media (GstRTSPSession * sess, const gchar * path,
+    gint * matched)
+{
+  return _gst_rtsp_session_get_media (sess, path, matched, FALSE);
+}
+
+/**
+ * gst_rtsp_session_dup_media:
+ * @sess: a #GstRTSPSession
+ * @path: the path for the media
+ * @matched: (out): the amount of matched characters
+ *
+ * Gets the session media for @path, increasing its reference count. @matched
+ * will contain the number of matched characters of @path.
+ *
+ * Returns: (transfer full) (nullable): the configuration for @path in @sess,
+ * should be unreferenced when no longer needed.
+ *
+ * Since: 1.20
+ */
+GstRTSPSessionMedia *
+gst_rtsp_session_dup_media (GstRTSPSession * sess, const gchar * path,
+    gint * matched)
+{
+  return _gst_rtsp_session_get_media (sess, path, matched, TRUE);
+}
+
 /**
  * gst_rtsp_session_filter:
  * @sess: a #GstRTSPSession
- * @func: (scope call) (allow-none): a callback
- * @user_data: (closure): user data passed to @func
+ * @func: (scope call) (allow-none) (closure user_data): a callback
+ * @user_data: user data passed to @func
  *
  * Call @func for each media in @sess. The result value of @func determines
  * what happens to the media. @func will be called with @sess
@@ -454,19 +485,38 @@ restart:
       res = func (sess, media, user_data);
 
       g_mutex_lock (&priv->lock);
-    } else
+    } else {
       res = GST_RTSP_FILTER_REF;
+    }
 
     changed = (cookie != priv->medias_cookie);
 
     switch (res) {
       case GST_RTSP_FILTER_REMOVE:
-        if (changed)
-          priv->medias = g_list_remove (priv->medias, media);
-        else
+        if (changed) {
+          GList *l;
+
+          walk = NULL;
+
+          for (l = priv->medias; l; l = l->next) {
+            if (l->data == media) {
+              walk = l;
+              break;
+            }
+          }
+        }
+
+        /* The media might have been removed from the list while the mutex was
+         * unlocked above. In that case there's nothing else to do here as the
+         * only reference to the media owned by this function is in the
+         * visited hash table and that is released in the end
+         */
+        if (walk) {
           priv->medias = g_list_delete_link (priv->medias, walk);
+          g_object_unref (media);
+        }
+
         cookie = ++priv->medias_cookie;
-        g_object_unref (media);
         break;
       case GST_RTSP_FILTER_REF:
         result = g_list_prepend (result, g_object_ref (media));
